@@ -5,14 +5,16 @@ Creates config file from logsheet. Will move into either utils or example folder
 import pandas as pd
 
 
-def create_config(tab, log, config_file):
+def create_config(log, config_file, tab=None):
     """
     Create config csv file out of tab in logsheet.
 
     Inputs:
-        :inst: (Instrument object) Instrument to which the config is related.
         :log: (string) path of the logsheet.
-        :config_file: (string) path of the desired concrete file
+        :config_file: (string) path of the desired concrete file, including the
+                    file name.
+        :tab: (string) tab of logsheet to be turned into.
+
     """
     if log[-3:] == "csv":
         logdf = pd.read_csv(log)
@@ -31,7 +33,7 @@ def create_config(tab, log, config_file):
             },
         )
     logdf = logdf[pd.notna(logdf["Start"])]
-    savedf = logdf.ix[:, ["Object", "ExpTime", "Filter", "Comments"]]
+    savedf = logdf[["Object", "ExpTime", "Filter", "Comments"]]
 
     nrows = len(logdf)
 
